/**
 * Copyright 2006 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nutch.parse.xml;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.io.UTF8;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.apache.nutch.crawl.CrawlDatum;
import org.apache.nutch.crawl.Inlinks;
import org.apache.nutch.indexer.IndexingException;
import org.apache.nutch.indexer.IndexingFilter;
import org.apache.nutch.metadata.Metadata;
import org.apache.nutch.parse.Parse;
import org.apache.nutch.parse.ParseData;

/**
 * Classe permettant d'ajouter de nouveaux champs rcuprs  partir du
 * XMLParser <br/> This Class add new fields to the index. This fields are
 * parsed by XMLParser
 * 
 * @author Rida Benjelloun (rida.benjelloun@doculibre.com)
 */
public class XMLIndexer implements IndexingFilter {
	public static final Log LOG = LogFactory
			.getLog("org.apache.nutch.parse.xml");

	private Configuration conf;
	

	public Document filter(Document doc, Parse parse, UTF8 url, CrawlDatum datum, Inlinks inlinks) throws IndexingException {

		ParseData pa = parse.getData();
		Metadata meta = pa.getParseMeta();
		
		String[] fields = meta.names();
		for (int i = 0; i < fields.length; i++) {
			String key = fields[i];
			String[] info = meta.get(key).split("-nxp-");
			Field field = null;
			if (info[0].trim().startsWith("nxpToIndex_")) {
				String fieldContent = info[0].trim().substring(11);
				if (info.length == 1) {
					field = new Field(key, fieldContent, Field.Store.YES,
							Field.Index.TOKENIZED);
					LOG.info("Field (" + key + ") (type = Text) : "
							+ fieldContent);
				} else if (info.length == 2) {
					field = getField(key, fieldContent.substring(11), info[1]
							.trim());
					LOG.info("Field (" + key + ") (type = " + info[1].trim()
							+ ") : " + fieldContent);
				} else if (info.length == 3) {
					field = getField(key, fieldContent, info[1].trim());
					Float boost = new Float(info[2].trim());
					field.setBoost(boost.floatValue());
					LOG.info("Field (" + key + ") (type = " + info[1].trim()
							+ ") (boost = " + info[2].trim() + "): "
							+ fieldContent);
				}
				doc.add(field);

			}

		}
		return doc;
	}

	private Field getField(String fieldName, String content, String type) {
		Field field = null;
		if (type.equalsIgnoreCase("text"))
			field = new Field(fieldName, content, Field.Store.YES,
					Field.Index.TOKENIZED);
		else if (type.equalsIgnoreCase("keyword"))
			field = new Field(fieldName, content, Field.Store.YES,
					Field.Index.UN_TOKENIZED);
		else if (type.equalsIgnoreCase("unindexed"))
			field = new Field(fieldName, content, Field.Store.YES,
					Field.Index.NO);
		else if (type.equalsIgnoreCase("unstored"))
			field = new Field(fieldName, content, Field.Store.NO,
					Field.Index.TOKENIZED);

		return field;
	}

	public void setConf(Configuration conf) {
		this.conf = conf;
	}

	public Configuration getConf() {
		return this.conf;
	}

}
