/**
 * Copyright 2006 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nutch.parse.xml.config;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

/**
 * 
 * Cette classe reprsente un champs field pars  partir du fichier de
 * configuration <br/> 
  
 * This class represent a field parsed from the xml config file. 
 *  
 * @author Rida Benjelloun (rida.benjelloun@doculibre.com)
 */
public class XMLField implements Serializable {

	private static final long serialVersionUID = 1L;

	private String fieldName;

	private String fieldXPath;

	private String fieldType;

	private float fieldBoost;

	private String fieldValue;

	private String[] fieldValues;

	public XMLField() {

	}

	public float getFieldBoost() {
		return fieldBoost;
	}

	public void setFieldBoost(float fieldBoost) {
		this.fieldBoost = fieldBoost;
	}

	public String getFieldName() {
		return fieldName;
	}

	public void setFieldName(String fieldName) {
		this.fieldName = fieldName;
	}

	public String getFieldType() {
		return fieldType;
	}

	public void setFieldType(String fieldType) {
		this.fieldType = fieldType;
	}

	public String getFieldValue() {
		return fieldValue;
	}

	public void setFieldValue(String fieldValue) {
		this.fieldValue = fieldValue;
	}

	public String[] getFieldValues() {
		return fieldValues;
	}

	public void setFieldValues(String[] fieldValues) {
		this.fieldValues = fieldValues;
	}

	public String getFieldXPath() {
		return fieldXPath;
	}

	public void setFieldXPath(String fieldXPath) {
		this.fieldXPath = fieldXPath;
	}

	/*
	 * public XMLField copy() throws CloneNotSupportedException{ return
	 * (XMLField)xf.clone(); }
	 */

	public Object clone() throws CloneNotSupportedException {
		try {
			final ByteArrayOutputStream out = new ByteArrayOutputStream();
			new ObjectOutputStream(out).writeObject(this);
			return new ObjectInputStream(new ByteArrayInputStream(out
					.toByteArray())).readObject();
		} catch (ClassNotFoundException e) {
			throw new RuntimeException("Internal error cloning object", e);
		} catch (IOException e) {
			throw new RuntimeException("Internal error cloning object", e);
		}
	}

}