/**
 * Copyright 2006 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nutch.parse.xml.config;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.nutch.parse.xml.XMLUtils;
import org.apache.nutch.util.NutchConfiguration;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.xpath.XPath;

/**
 * Classe permettant de charger le fichier de configuration <br/> This class
 * load the xml config file.
 * 
 * @author Rida Benjelloun (rida.benjelloun@doculibre.com)
 */
public class XMLParserConfig {

	public static final Log LOG = LogFactory
			.getLog("org.apache.nutch.parse.xml");

	private static XMLParserConfig xpc = null;

	private Map xmlIndexerProperties;

	private XMLParserConfig() {
	}

	public static XMLParserConfig getInstance() {
		if (xpc == null) {

			InputStream configIs = NutchConfiguration.create()
					.getConfResourceAsInputStream("xmlparser-conf.xml");

			LOG.info("XMLParser config path : "
					+ NutchConfiguration.create().get("xmlparser-conf.xml"));
			xpc = new XMLParserConfig();
			Document doc = XMLUtils.parseXml(configIs);
			xpc = populateConfig(doc);
		}
		return xpc;
	}

	private static XMLParserConfig populateConfig(Document doc) {

		Map hm = new HashMap();
		Collection fieldsColl = null;
		try {
			List ls = XPath.selectNodes(doc, "//xmlIndexerProperties");
			Iterator i = ls.iterator();
			while (i.hasNext()) {
				XMLIndexerProperties xip = new XMLIndexerProperties();
				fieldsColl = new ArrayList();
				Element elemNode = (Element) i.next();
				String type = elemNode.getAttributeValue("type");
				xip.setType(type);
				String nameSpace = elemNode.getAttributeValue("namespace");
				xip.setNameSpace(nameSpace);
				if (elemNode.getAttribute("nodeXpath") != null) {
					String nodeXpath = elemNode.getAttributeValue("namespace");
					xip.setNodeXpath(nodeXpath);
				}
				List fieldList = XPath.selectNodes(elemNode, "field");

				for (int j = 0; j < fieldList.size(); j++) {
					Element elem = (Element) fieldList.get(j);
					XMLField xf = populateXMLField(elem);
					fieldsColl.add(xf);
				}
				xip.setXmlFields(fieldsColl);
				hm.put(xip.getNameSpace(), xip);
			}

		} catch (JDOMException e) {

		}
		xpc.setXMLIndexerProperties(hm);
		return xpc;
	}

	public Map getXMLIndexerProperties() {
		return xmlIndexerProperties;
	}

	public void setXMLIndexerProperties(Map xmlIndexerProperties) {
		this.xmlIndexerProperties = xmlIndexerProperties;
	}

	private static XMLField populateXMLField(Element elem) {
		XMLField xf = new XMLField();
		if (elem.getAttribute("name") != null)
			xf.setFieldName(elem.getAttributeValue("name"));
		if (elem.getAttribute("xpath") != null)
			xf.setFieldXPath(elem.getAttributeValue("xpath"));
		if (elem.getAttribute("type") != null)
			xf.setFieldType(elem.getAttributeValue("type"));
		if (elem.getAttribute("boost") != null) {
			Float f = new Float(elem.getAttributeValue("boost"));
			xf.setFieldBoost(f.floatValue());
		}
		return xf;
	}

}
