/**
 * Copyright 2006 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nutch.parse.xml;

import junit.framework.TestCase;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.io.UTF8;
import org.apache.nutch.crawl.CrawlDatum;
import org.apache.nutch.parse.Parse;
import org.apache.nutch.parse.ParseException;
import org.apache.nutch.parse.ParseUtil;
import org.apache.nutch.protocol.Content;
import org.apache.nutch.protocol.Protocol;
import org.apache.nutch.protocol.ProtocolException;
import org.apache.nutch.protocol.ProtocolFactory;
import org.apache.nutch.util.NutchConfiguration;

/**
 * @author Rida Benjelloun (rida.benjelloun@doculibre.com)
 */
public class TestXmlParser extends TestCase {

	private String fileSeparator = System.getProperty("file.separator");

	private String sampleDir = System.getProperty("test.data", ".");

	private String[] sampleFiles = { "xmltest.xml" };

	private String expectedText = "XMLParser parse XML data using namespace and XPath";

	public TestXmlParser(String name) {
		super(name);
	}

	protected void setUp() {
	}

	protected void tearDown() {
	}

	public void testIt() throws ProtocolException, ParseException {
		String urlString;
		Protocol protocol;
		Content content;

		Parse parse;

		for (int i = 0; i < sampleFiles.length; i++) {
			urlString = "file:" + sampleDir + fileSeparator + sampleFiles[i];

			Configuration conf = NutchConfiguration.create();
			protocol = new ProtocolFactory(conf).getProtocol(urlString);
			content = protocol.getProtocolOutput(new UTF8(urlString),
					new CrawlDatum()).getContent();
			parse = new ParseUtil(conf)
					.parseByExtensionId("parse-xml", content);

			int index = parse.getText().indexOf(expectedText);
			assertTrue(index > 0);
		}

	}

}
